==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/generic/iggwidgetmisc.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Some miscenallous widgets
//

#ifndef IGGWIDGETMISC_H
#define IGGWIDGETMISC_H


#include "iggwidget.h"


class ibgWidgetButtonSubject;
class ibgWidgetEntrySubject;
class ibgWidgetMultiImageDisplayAreaSubject;
class ibgWidgetRadioBoxSubject;
class ibgWidgetSpinBoxSubject;


class iggWidgetImageFlipper : public iggWidget
{

public:

	iggWidgetImageFlipper(iggFrame *parent);

	//
	//  Manual operation
	//
	void Advance();
	void Reset();

	//
	//  Automatic operation
	//
	void Start();
	void Abort();

protected:

	virtual bool UpdateWidgetBody();
	virtual void OnVoid1Body();

	ibgWidgetMultiImageDisplayAreaSubject *mSubject;
};


class iggWidgetLogoFlipper : public iggWidgetImageFlipper
{

public:

	iggWidgetLogoFlipper(iggFrame *parent);
};


class iggWidgetNumberDisplay : public iggWidget
{

public:

	iggWidgetNumberDisplay(const iString &title, iggFrame *parent);

	void Display(double v, int prec = -1);

protected:

	virtual bool UpdateWidgetBody();

	ibgWidgetEntrySubject *mSubject;
};


class iggWidgetTextDisplay : public iggWidget
{

public:

	iggWidgetTextDisplay(const iString &title, iggFrame *parent);

	void Display(const iString &text);

protected:

	virtual bool UpdateWidgetBody();

	ibgWidgetEntrySubject *mSubject;
};


class iggWidgetSimpleRadioBox : public iggWidget
{

public:

	iggWidgetSimpleRadioBox(int cols, const iString &text, iggFrame *parent);

	void InsertItem(const iString &text, int index = -1);
	int GetValue() const;
	void SetValue(int v);

protected:

	virtual bool UpdateWidgetBody();

	ibgWidgetRadioBoxSubject *mSubject;
};


class iggWidgetSimpleSpinBox : public iggWidget
{

public:

	iggWidgetSimpleSpinBox(int min, int max, int step, const iString &text, iggFrame *parent);

	void SetValue(int v);
	int GetValue() const;

protected:

	virtual bool UpdateWidgetBody();

	ibgWidgetSpinBoxSubject *mSubject;
};


class iggWidgetSimpleCheckBox : public iggWidget
{

public:

	iggWidgetSimpleCheckBox(const iString &title, iggFrame *parent);

	bool IsDown() const;

protected:

	virtual bool UpdateWidgetBody();
	virtual void OnVoid1Body();
	virtual void OnChecked(bool s) = 0;

	ibgWidgetButtonSubject *mSubject;
};

#endif  //  IGGWIDGETMISC_H

==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/shells/generic/iggwidgetmisc.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Some miscenallous widgets
//

#ifndef IGGWIDGETMISC_H
#define IGGWIDGETMISC_H


#include "iggwidget.h"


class ibgWidgetButtonSubject;
class ibgWidgetEntrySubject;
class ibgWidgetMultiImageDisplayAreaSubject;
class ibgWidgetRadioBoxSubject;
class ibgWidgetSpinBoxSubject;


class iggWidgetImageFlipper : public iggWidget
{

public:

	iggWidgetImageFlipper(iggFrame *parent);

	//
	//  Manual operation
	//
	void Advance();
	void Reset();

	//
	//  Automatic operation
	//
	void Start();
	void Abort();

protected:

	virtual void UpdateWidgetBody();
	virtual void OnVoid1Body();

	ibgWidgetMultiImageDisplayAreaSubject *mSubject;
};


class iggWidgetLogoFlipper : public iggWidgetImageFlipper
{

public:

	iggWidgetLogoFlipper(iggFrame *parent);
};


class iggWidgetNumberDisplay : public iggWidget
{

public:

	iggWidgetNumberDisplay(const iString &title, iggFrame *parent);

	void Display(double v, int prec = -1);

protected:

	virtual void UpdateWidgetBody();

	ibgWidgetEntrySubject *mSubject;
};


class iggWidgetTextDisplay : public iggWidget
{

public:

	iggWidgetTextDisplay(const iString &title, iggFrame *parent);

	void Display(const iString &text);

protected:

	virtual void UpdateWidgetBody();

	ibgWidgetEntrySubject *mSubject;
};


class iggWidgetSimpleRadioBox : public iggWidget
{

public:

	iggWidgetSimpleRadioBox(int cols, const iString &text, iggFrame *parent);

	void InsertItem(const iString &text, int index = -1);
	int GetValue() const;
	void SetValue(int v);

protected:

	virtual void UpdateWidgetBody();

	ibgWidgetRadioBoxSubject *mSubject;
};


class iggWidgetSimpleSpinBox : public iggWidget
{

public:

	iggWidgetSimpleSpinBox(int min, int max, int step, const iString &text, iggFrame *parent);

	void SetValue(int v);
	int GetValue() const;

protected:

	virtual void UpdateWidgetBody();

	ibgWidgetSpinBoxSubject *mSubject;
};


class iggWidgetSimpleCheckBox : public iggWidget
{

public:

	iggWidgetSimpleCheckBox(const iString &title, iggFrame *parent);

	bool IsDown() const;

protected:

	virtual void UpdateWidgetBody();
	virtual void OnVoid1Body();
	virtual void OnChecked(bool s) = 0;

	ibgWidgetButtonSubject *mSubject;
};

#endif  //  IGGWIDGETMISC_H
